@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.38 2004/01/04 22:03:23 sts Exp $
+# $Id: Split.pm,v 0.39 2004/01/04 22:03:23 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use 5.6.1;
 use strict;
@@ -72,11 +72,25 @@ Dir::Split - Split files of a directory to subdirectories.
 
 C<Dir::Split> moves files to either numbered or characteristic subdirectories.
 
+=head2 numeric splitting
+
+Numeric splitting is an attempt to gather files from a source directory and
+split them to numbered subdirectories within a target directory. Its purpose is
+to automate the archiving of a great amount of files, that are likely to be indexed
+by numbers.
+
+=head2 characteristic splitting
+
+Characteristic splitting allows indexing by using leading characters of filenames.
+While numeric splitting is being characterised by dividing file amounts, characteristic
+splitting tries to keep up the contentual recognition of data.
+
 =head1 CONSTRUCTOR
 
 =head2 new
 
-Creates an object. C<%options> contains the key / value pairs which will influence the splitting process.
+Creates an object. C<%options> contains the key / value pairs
+which will influence the splitting process.
 
  $dir = Dir::Split->new (\%options);
 
@@ -100,7 +114,7 @@ sub new {
 #
 
 sub _tie_var {
-    my $Opt_ref = $_[0];
+    my $opt_ref = $_[0];
 
     my %assign = (  mode    =>    'mode',
 
@@ -121,13 +135,13 @@ sub _tie_var {
                     },
     );
     my %assigned;
-    foreach my $key (keys %$Opt_ref) {
-        if (ref $$Opt_ref{$key} eq 'HASH') {
-            foreach ( keys %{$$Opt_ref{$key}} ) {
-                $assigned{$assign{$key}{$_}} = $$Opt_ref{$key}{$_};
+    foreach my $key (keys %$opt_ref) {
+        if (ref $$opt_ref{$key} eq 'HASH') {
+            foreach ( keys %{$$opt_ref{$key}} ) {
+                $assigned{$assign{$key}{$_}} = $$opt_ref{$key}{$_};
             }
         }
-        else { $assigned{$assign{$key}} = $$Opt_ref{$key} }
+        else { $assigned{$assign{$key}} = $$opt_ref{$key} }
     }
     return \%assigned;
 };
@@ -188,13 +202,14 @@ sub split {
 
         # engine
         $o->_sort_files() if $o->{'mode'} eq 'num';
-        my $sub_suffix = "_suffix_$o->{'mode'}";
-        $o->$sub_suffix();
+        $o->_suffix();
         $o->_move();
     }
     # no files? exit.
     else { $Ret_Status = NO_ACTION }
 
+    $Ret_Status = FAILURE if %failure;
+
     return $Ret_Status;
 }
 
@@ -264,6 +279,9 @@ sub _sanity_input {
             unless ($o->{'case'} eq 'lower' || $o->{'case'} eq 'upper') {
                 $err_input = $err_msg{'case'}; last;
             }
+            unless ($o->{'length'} > 0) {
+                $err_input = $err_msg{'length'}; last;
+            }
         }
     }
     croak $err_input if $err_input;
@@ -296,7 +314,7 @@ sub _gather_files {
 #
 # _sort_files()
 #
-# Sorts the files if numeric splitting.
+# Sorts the files.
 #
 
 sub _sort_files {
@@ -310,21 +328,25 @@ sub _sort_files {
         @Files = map lc, @Files;
 
         if ($o->{'f_sort'} eq '+') { @Files = sort @Files }
-        elsif ($o->{'f_sort'} eq '-') { @Files = reverse @Files }
+        else { @Files = reverse @Files }
     }
 }
 
 #
-# _suffix_num()
+# _suffix()
 #
-# Sub handler for numeric suffixes.
+# Sub handler for suffixes.
 #
 
-sub _suffix_num {
+sub _suffix {
     my $o = $_[0];
 
-    $o->_suffix_num_contin() if $o->{'num_contin'} == 1;
-    $o->_suffix_num_sum_up();
+    if ($o->{'mode'} eq 'num') {
+        $o->_suffix_num_contin() if $o->{'num_contin'} == 1;
+        $o->_suffix_num_sum_up();
+    } else {
+        $o->_suffix_char();
+    }
 }
 
 #
@@ -373,19 +395,21 @@ sub _suffix_num_sum_up {
 #
 # _suffix_char()
 #
-# Evaluates all filenames in the source directory
-# and stores them in a hash associated with their
-# leading character.
+# Evaluates filenames in source directory
+# and stores them in a hash associated with the leading
+# characters of their filenames.
 #
 
 sub _suffix_char {
     my $o = $_[0];
 
     foreach my $file (@Files) {
-        ($_) = $file =~ /^(.)/;
+        $_ = $file;
+        s/\s//g if /\s/; # whitespaces
+        ($_) = /^(.{$o->{'length'}})/;
         if ($_ =~ /\w/) {
-            if ($o->{'case'} eq 'upper') { $_ = uc $_ }
-            elsif ($o->{'case'} eq 'lower') { $_ = lc $_ }
+            if ($o->{'case'} eq 'lower') { $_ = lc $_ }
+            else { $_ = uc $_ }
         }
         push @{$F_names_char{$_}}, $file;
     }
@@ -456,9 +480,9 @@ sub _dir_read {
     shift; my ($dir, $files_ref) = @_;
 
     opendir D, $dir
-      or croak qq~Could not open dir $dir for read-access: $!~;
+      or croak qq~could not open dir $dir for read-access: $!~;
     @$files_ref = readdir D; splice @$files_ref, 0, 2;
-    closedir D or croak qq~Could not close dir $dir: $!~;
+    closedir D or croak qq~could not close dir $dir: $!~;
 }
 
 #
@@ -474,7 +498,7 @@ sub _mkpath {
 
     return if -e $Path;
     mkpath $Path, $o->{'verbose'} or
-      die "Directory $Path could not be created: $!\n";
+      croak "dir $Path could not be created: $!";
 
     $track{'target'}{'dirs'}++;
 }
@@ -483,7 +507,7 @@ sub _mkpath {
 # _cp_unlink ($file)
 #
 # Copies files and unlinks them.
-# Upon existing files / failures debug data.
+# Upon existing files / failures, debug data.
 #
 
 sub _cp_unlink {
@@ -499,20 +523,18 @@ sub _cp_unlink {
 
     unless (cp $file, $path_full) {
         push @{$failure{'copy'}}, $path_full;
-        $Ret_Status = FAILURE unless $Ret_Status eq FAILURE;
         return;
     }
+    $track{'target'}{'files'}++;
+
     unless (unlink $file) {
         push @{$failure{'unlink'}}, $file;
-        $Ret_Status = FAILURE unless $Ret_Status eq FAILURE;
         return;
     }
-
-    $track{'target'}{'files'}++;
 }
 
 #
-# _exists_and_not_override ($item, $path)
+# _exists_and_not_override ($path)
 #
 # Looks out for existing files.
 #
@@ -520,13 +542,9 @@ sub _cp_unlink {
 sub _exists_and_not_override {
     my ($o, $path) = @_;
 
-    if (-e $path) {
-        if ($o->{'override'} != 1) {
-            if ($Ret_Status ne FAILURE && $Ret_Status ne EXISTS) {
-                $Ret_Status = EXISTS;
-            }
-            return 1;
-        }
+    if (-e $path && $o->{'override'} != 1) {
+        $Ret_Status = EXISTS;
+        return 1;
     }
 
     return 0;
@@ -649,9 +667,9 @@ may cause interfering with existing files.
 
 =item B<suffix / length>
 
-(i) - length of the suffix in characters.
+(i) - character length of the suffix.
 
-This option will have no effect if its smaller than the current size
+This option will have no effect if its smaller than the current length
 of the highest suffix number.
 
 =back
@@ -661,7 +679,7 @@ of the highest suffix number.
 =head2 characteristic
 
 Split files to subdirectories with a characteristic suffix. Files
-are assigned to subdirectories which suffixes equal the leading character
+are assigned to subdirectories which suffixes equal the leading character (s)
 of their filenames.
 
     %options = (  mode    =>    'char',
@@ -675,7 +693,8 @@ of their filenames.
                   sub_dir => {  identifier  =>     'sub',
                   },
                   suffix  => {  separator   =>       '-',
-                                case        =>   'lower',
+                                case        =>   'upper',
+                                length      =>         1,
                   },
 
     );
@@ -733,6 +752,18 @@ subdirectories.
    lower
    upper
 
+=item B<suffix / length>
+
+(i) - character length of the suffix.
+
+< 4 is highly recommended (26 (alphabet) ^ 3 == 17'576 suffix possibilites).
+C<Dir::Split> will not prevent using suffix lengths greater than 3. Imagine
+splitting 1'000 files and using a character length > 20. The file rate per
+subdirectory will almost certainly approximate 1/1 - which equals 1'000
+subdirectories.
+
+Whitespaces in suffixes will be removed.
+
 =back
 
 =back
@@ -759,7 +790,7 @@ Above example: directory consisting 512 files successfully splitted to 128 direc
 
 If C<split()> returns a I<EXISTS>, this implys that the B<override> option is disabled and
 files could not be moved due to existing files within the target subdirectories; they will have
-their paths appearing in the according keys in C<%Dir::Split::exists>.
+their paths appearing in C<@Dir::Split::exists>.
 
    file    @Dir::Split::exists    # existing files, not attempted to
                                   # be overwritten.
@@ -790,7 +821,7 @@ Assuming I</source> contains 5 files:
 
 After splitting the directory tree in I</target> will look as following:
 
-=head2 numeric splitting
+B<numeric splitting>
 
     +- system-00001
     +-- _12.tmp
@@ -801,7 +832,7 @@ After splitting the directory tree in I</target> will look as following:
     +- system-00003
     +-- jkl.tmp
 
-=head2 characteristic splitting
+B<characteristic splitting>
 
     +- system-_
     +-- _12.tmp
@@ -814,14 +845,42 @@ After splitting the directory tree in I</target> will look as following:
     +- system-j
     +-- jkl.tmp
 
-=head1 DEPENDENCIES
+=head1 FAQ
 
-C<Perl 5.6.1>; C<File::Copy>, C<File::Path>, C<File::Spec>.
+=over 4
+
+=item Has the functionality of Dir::Split been tested?
+
+Yes. I may not have covered all edging cases,
+but it should behave mostly I<sane>, if certain options
+such as numbering continuation are enabled and others,
+like overriding, are disabled.
+
+=item Portability?
+
+Has not yet been extensively tested. Dir::Split relies mostly
+upon File:: nested modules in spite of filesystem
+operation such as copying, unlinking and selecting
+an appropriate path separator; thus it should
+probably be portable.
+
+=item Will you add any additional features?
+
+Not unless they're a real benefit. Dir::Split is
+already heavyweight enough and I am rather careful
+in terms of new inclusions; proposals towards additions
+should be well grounded.
+
+=back
 
 =head1 CAVEATS
 
 Recursive source directory processing is not supported;
-existing directories within the source directory will be ignored.
+existing directories within the source directory will silently be ignored.
+
+=head1 DEPENDENCIES
+
+C<Perl 5.6.1>; C<File::Copy>, C<File::Path>, C<File::Spec>.
 
 =head1 SEE ALSO
 
